"""
Module containing simple demonstration functions.

This module provides basic example functions to demonstrate
simple Python functionality.

Functions
---------
hello_world()
    Print 'Hello World!' to the console.
"""


def hello_world():
    """
    Print 'Hello World!' to the console.

    Parameters
    ----------
    None

    Returns
    -------
    None

    Notes
    -----
    - This function simply prints the message 'Hello World!' to the standard output.
    """
    print('Hello World!')
